# GoogleAnalyticsSourceFormPropertiesReportDefinitions

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** | A unique ID for the custom report. | [optional]
**name** | **str** | The name of the custom report. This will be used to create the name of the corresponding table in the destination.  | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


